Vimeo (OAuth 2)
---------------

App registration (get your key and secret here)
    https://developer.vimeo.com/apps

Development callback URL
    http://localhost:8000/accounts/vimeo_oauth2/login/callback/

VK
--

App registration
    https://vk.com/editapp?act=create

Development callback URL ("Site address")
    http://localhost
